#ifndef OCARINA_BUTTON_H
#define OCARINA_BUTTON_H

#include <string>
using namespace std;

#include <ocarina/gtk.h>

GtkWidget *make_button(const gchar *stockid,
		       void (* func)(GtkWidget *, GdkEvent *, gpointer),
		       bool show);

GtkWidget *make_text_button(const gchar *stockid,
			    string text,
			    void (* func)(GtkWidget *, GdkEvent *, gpointer),
			    bool show);


GtkWidget *make_play_button();
GtkWidget *make_pause_button();
GtkWidget *make_stop_button();
GtkWidget *make_rewind_button();
GtkWidget *make_forward_button();

GtkWidget *make_open_button();
GtkWidget *make_volume_button();

enum button_list_t {
	PLAY_BUTTON_LIST,
	PAUSE_BUTTON_LIST,
};

void show_button_list(button_list_t);
void hide_button_list(button_list_t);

#endif /* OCARINA_BUTTON_H */
